@@ -1,4 +1,8 @@
+# include default tkinter symbols
 from tkinter import *
+
+# inheriting widgets
+from .tkroot import Tk
 from .floatingwindow import FloatingWindow
 from .graph import Graph
 from .image import Image
@@ -6,5 +10,10 @@ from .tabbedframe import TabbedFrame
 from .overlaywindow import OverlayWindow
 from .input import Slider, Dial
 from .timeplot import TimePlot
-from .style import style, make_reactive
-from .color import Color
\ No newline at end of file
+
+# appliers
+from .mixins import Reactive
+from .style import Style
+
+# misc
+from .color import Color
